@@ -19,6 +19,9 @@ from django.utils.encoding import force_str
 
 import requests, base64, random, time, json
 
+
+from IBMCloud import Storage
+
 __all__ = ('Storage', 'FileSystemStorage', 'DefaultStorage', 'default_storage')
 
 
@@ -221,6 +224,7 @@ class FileSystemStorage(Storage):
     def _open(self, name, mode='rb'):
         return File(open(self.path(name), mode))
 
+    '''
     def fn_base64(self, fn):
         f = open(fn, 'rb')
         fnb64 = base64.b64encode(f.read()).decode('utf-8')
@@ -242,10 +246,6 @@ class FileSystemStorage(Storage):
 
     def put_data(self, image_name, image_path):
         
-        '''
-        https://developer.github.com/enterprise/2.16/v3/repos/contents/
-        '''
-
         token = settings.GIT_TOKEN
         headers = {"Authorization": 'token '+ token}        
 
@@ -308,6 +308,7 @@ class FileSystemStorage(Storage):
             print('delete success')
         else:
             print('status==============' + str(rs) + "---------------------------"+ str(r.text))
+    '''
 
     def _save(self, name, content):
         full_path = self.path(name)
@@ -380,7 +381,9 @@ class FileSystemStorage(Storage):
             os.chmod(full_path, self.file_permissions_mode)
 
         # Store filenames with forward slashes, even on Windows.
-        self.put_data(name, full_path)
+        #self.put_data(name, full_path)
+        Storage.upload_large_file("django", name, full_path)
+        
 
         return name.replace('\\', '/')
 
@@ -400,7 +403,8 @@ class FileSystemStorage(Storage):
             pass
         
         print("name=======" + name)
-        self.delete_data(name)
+        #self.delete_data(name)
+        Storage.delete_item(self, name)
 
 
     def exists(self, name):
